@@ -510,7 +510,7 @@ baseof: {{ block "main" . }}{{ end }}
 		q := tplimpl.TemplateQuery{
 			Path:     "/baz",
 			Category: tplimpl.CategoryLayout,
-			Desc:     tplimpl.TemplateDescriptor{Kind: kinds.KindPage, Layout: "single", OutputFormat: "html"},
+			Desc:     tplimpl.TemplateDescriptor{Kind: kinds.KindPage, LayoutFromTemplate: "single", OutputFormat: "html"},
 		}
 		for i := 0; i < b.N; i++ {
 			store.LookupPagesLayout(q)
@@ -521,7 +521,7 @@ baseof: {{ block "main" . }}{{ end }}
 		q := tplimpl.TemplateQuery{
 			Path:     "/foo/bar",
 			Category: tplimpl.CategoryLayout,
-			Desc:     tplimpl.TemplateDescriptor{Kind: kinds.KindPage, Layout: "single", OutputFormat: "html"},
+			Desc:     tplimpl.TemplateDescriptor{Kind: kinds.KindPage, LayoutFromTemplate: "single", OutputFormat: "html"},
 		}
 		for i := 0; i < b.N; i++ {
 			store.LookupPagesLayout(q)
@@ -648,9 +648,6 @@ layout: mylayout
 
 	b := hugolib.Test(t, files, hugolib.TestOptWarn())
 
-	// s := b.H.Sites[0].TemplateStore
-	// s.PrintDebug("", tplimpl.CategoryLayout, os.Stdout)
-
 	b.AssertLogContains("! WARN")
 
 	// Single pages.
@@ -827,7 +824,46 @@ func TestPartialHTML(t *testing.T) {
 }
 
 // Issue #13593.
-func TestNoGoat(t *testing.T) {
+func TestGoatAndNoGoat(t *testing.T) {
+	t.Parallel()
+
+	files := `
+-- hugo.toml --
+-- content/_index.md --
+---
+title: "Home"
+---
+
+
+§§§
+printf "Hello, world!"
+§§§
+
+
+§§§ goat
+.---.     .-.       .-.       .-.     .---.
+| A +--->| 1 |<--->| 2 |<--->| 3 |<---+ B |
+'---'     '-'       '+'       '+'     '---'
+§§§
+
+
+
+-- layouts/all.html --
+{{ .Content }}
+
+`
+
+	b := hugolib.Test(t, files)
+
+	// Basic code block.
+	b.AssertFileContent("public/index.html", "<code>printf &#34;Hello, world!&#34;\n</code>")
+
+	// Goat code block.
+	b.AssertFileContent("public/index.html", "Menlo,Lucida")
+}
+
+// Issue #13595.
+func TestGoatAndNoGoatCustomTemplate(t *testing.T) {
 	t.Parallel()
 
 	files := `
@@ -841,6 +877,16 @@ title: "Home"
 printf "Hello, world!"
 §§§
 
+§§§ goat
+.---.     .-.       .-.       .-.     .---.
+| A +--->| 1 |<--->| 2 |<--->| 3 |<---+ B |
+'---'     '-'       '+'       '+'     '---'
+§§§
+
+
+
+-- layouts/_markup/render-codeblock.html --
+_markup/render-codeblock.html
 -- layouts/all.html --
 {{ .Content }}
 
@@ -848,7 +894,51 @@ printf "Hello, world!"
 
 	b := hugolib.Test(t, files)
 
-	b.AssertFileContent("public/index.html", "Hello, world!")
+	// Basic code block.
+	b.AssertFileContent("public/index.html", "_markup/render-codeblock.html")
+
+	// Goat code block.
+	b.AssertFileContent("public/index.html", "Menlo,Lucida")
+}
+
+func TestGoatcustom(t *testing.T) {
+	t.Parallel()
+
+	files := `
+-- hugo.toml --
+-- content/_index.md --
+---
+title: "Home"
+---
+
+§§§
+printf "Hello, world!"
+§§§
+
+§§§ goat
+.---.     .-.       .-.       .-.     .---.
+| A +--->| 1 |<--->| 2 |<--->| 3 |<---+ B |
+'---'     '-'       '+'       '+'     '---'
+§§§
+
+
+
+-- layouts/_markup/render-codeblock.html --
+_markup/render-codeblock.html
+-- layouts/_markup/render-codeblock-goat.html --
+_markup/render-codeblock-goat.html
+-- layouts/all.html --
+{{ .Content }}
+
+`
+
+	b := hugolib.Test(t, files)
+
+	// Basic code block.
+	b.AssertFileContent("public/index.html", "_markup/render-codeblock.html")
+
+	// Custom Goat code block.
+	b.AssertFileContent("public/index.html", "_markup/render-codeblock.html_markup/render-codeblock-goat.html")
 }
 
 // Issue #13515
@@ -1002,6 +1092,63 @@ s2.
 	})
 }
 
+func TestStandardLayoutInFrontMatter13588(t *testing.T) {
+	t.Parallel()
+
+	files := `
+-- hugo.toml --
+disableKinds = ['home','page','rss','sitemap','taxonomy','term']
+-- content/s1/_index.md --
+---
+title: s1
+---
+-- content/s2/_index.md --
+---
+title: s2
+layout: list
+---
+-- content/s3/_index.md --
+---
+title: s3
+layout: single
+---
+-- layouts/list.html --
+list.html
+-- layouts/section.html --
+section.html
+-- layouts/single.html --
+single.html
+`
+
+	b := hugolib.Test(t, files)
+
+	b.AssertFileContent("public/s1/index.html", "section.html")
+	b.AssertFileContent("public/s2/index.html", "list.html")   // fail
+	b.AssertFileContent("public/s3/index.html", "single.html") // fail
+}
+
+func TestIssue13605(t *testing.T) {
+	t.Parallel()
+
+	files := `
+-- hugo.toml --
+disableKinds = ['home','rss','section','sitemap','taxonomy','term']
+-- content/s1/p1.md --
+---
+title: p1
+---
+{{< sc >}}
+-- layouts/s1/_shortcodes/sc.html --
+layouts/s1/_shortcodes/sc.html
+-- layouts/single.html --
+{{ .Content }}
+`
+
+	b := hugolib.Test(t, files)
+
+	b.AssertFileContent("public/s1/p1/index.html", "layouts/s1/_shortcodes/sc.html")
+}
+
 func TestSkipDotFiles(t *testing.T) {
 	t.Parallel()
 
@@ -1016,3 +1163,44 @@ All.
 	// Just make sure it doesn't fail.
 	hugolib.Test(t, files)
 }
+
+func TestPartialsLangIssue13612(t *testing.T) {
+	t.Parallel()
+
+	files := `
+-- hugo.toml --
+disableKinds = ['page','section','sitemap','taxonomy','term']
+
+defaultContentLanguage = 'ru'
+defaultContentLanguageInSubdir = true
+
+[languages.ru]
+weight = 1
+
+[languages.en]
+weight = 2
+
+[outputs]
+home = ['html','rss']
+
+-- layouts/_partials/comment.en.html --
+layouts/_partials/comment.en.html
+-- layouts/_partials/comment.en.xml --
+layouts/_partials/comment.en.xml
+-- layouts/_partials/comment.ru.html --
+layouts/_partials/comment.ru.html
+-- layouts/_partials/comment.ru.xml --
+layouts/_partials/comment.ru.xml
+-- layouts/home.html --
+{{ partial (print "comment." (default "ru" .Lang) ".html") . }}
+-- layouts/home.rss.xml --
+{{ partial (print "comment." (default "ru" .Lang) ".xml") . }}
+`
+
+	b := hugolib.Test(t, files)
+
+	b.AssertFileContent("public/en/index.html", "layouts/_partials/comment.en.html")
+	b.AssertFileContent("public/en/index.xml", "layouts/_partials/comment.en.xml")   // fail
+	b.AssertFileContent("public/ru/index.html", "layouts/_partials/comment.ru.html") // fail
+	b.AssertFileContent("public/ru/index.xml", "layouts/_partials/comment.ru.xml")   // fail
+}
